'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
/**
 * @file Exposes ABI arrays for all supported contract interfaces
 * @author Ivan Violentov <ivan.violentov@jibrel.network>
 */

var Controller = [{
  constant: true,
  inputs: [{
    name: '_manager',
    type: 'address'
  }, {
    name: '_permissionName',
    type: 'string'
  }],
  name: 'isManagerAllowed',
  outputs: [{
    name: '',
    type: 'bool'
  }],
  payable: false,
  stateMutability: 'view',
  type: 'function'
}, {
  constant: true,
  inputs: [{
    name: '_owner',
    type: 'address'
  }, {
    name: '_spender',
    type: 'address'
  }],
  name: 'getAllowance',
  outputs: [{
    name: '',
    type: 'uint256'
  }],
  payable: false,
  stateMutability: 'view',
  type: 'function'
}, {
  constant: false,
  inputs: [{
    name: '_crydrStorage',
    type: 'address'
  }],
  name: 'setCrydrStorage',
  outputs: [],
  payable: false,
  stateMutability: 'nonpayable',
  type: 'function'
}, {
  constant: false,
  inputs: [{
    name: '_msgsender',
    type: 'address'
  }, {
    name: '_from',
    type: 'address'
  }, {
    name: '_to',
    type: 'address'
  }, {
    name: '_value',
    type: 'uint256'
  }],
  name: 'transferFrom',
  outputs: [],
  payable: false,
  stateMutability: 'nonpayable',
  type: 'function'
}, {
  constant: false,
  inputs: [],
  name: 'cancelOwnershipOffer',
  outputs: [],
  payable: false,
  stateMutability: 'nonpayable',
  type: 'function'
}, {
  constant: true,
  inputs: [{
    name: '_manager',
    type: 'address'
  }, {
    name: '_permissionName',
    type: 'string'
  }],
  name: 'isPermissionGranted',
  outputs: [{
    name: '',
    type: 'bool'
  }],
  payable: false,
  stateMutability: 'view',
  type: 'function'
}, {
  constant: false,
  inputs: [{
    name: '_account',
    type: 'address'
  }, {
    name: '_value',
    type: 'uint256'
  }],
  name: 'mint',
  outputs: [],
  payable: false,
  stateMutability: 'nonpayable',
  type: 'function'
}, {
  constant: false,
  inputs: [],
  name: 'pauseContract',
  outputs: [],
  payable: false,
  stateMutability: 'nonpayable',
  type: 'function'
}, {
  constant: false,
  inputs: [{
    name: '_account',
    type: 'address'
  }],
  name: 'unblockAccount',
  outputs: [],
  payable: false,
  stateMutability: 'nonpayable',
  type: 'function'
}, {
  constant: false,
  inputs: [{
    name: '_manager',
    type: 'address'
  }],
  name: 'enableManager',
  outputs: [],
  payable: false,
  stateMutability: 'nonpayable',
  type: 'function'
}, {
  constant: true,
  inputs: [],
  name: 'getPaused',
  outputs: [{
    name: '',
    type: 'bool'
  }],
  payable: false,
  stateMutability: 'view',
  type: 'function'
}, {
  constant: true,
  inputs: [],
  name: 'getAssetID',
  outputs: [{
    name: '',
    type: 'string'
  }],
  payable: false,
  stateMutability: 'view',
  type: 'function'
}, {
  constant: false,
  inputs: [{
    name: '_viewApiStandardName',
    type: 'string'
  }],
  name: 'removeCrydrView',
  outputs: [],
  payable: false,
  stateMutability: 'nonpayable',
  type: 'function'
}, {
  constant: false,
  inputs: [{
    name: '_account',
    type: 'address'
  }],
  name: 'blockAccount',
  outputs: [],
  payable: false,
  stateMutability: 'nonpayable',
  type: 'function'
}, {
  constant: false,
  inputs: [{
    name: '_manager',
    type: 'address'
  }, {
    name: '_permissionName',
    type: 'string'
  }],
  name: 'revokeManagerPermission',
  outputs: [],
  payable: false,
  stateMutability: 'nonpayable',
  type: 'function'
}, {
  constant: false,
  inputs: [{
    name: '_account',
    type: 'address'
  }, {
    name: '_value',
    type: 'uint256'
  }],
  name: 'unblockAccountFunds',
  outputs: [],
  payable: false,
  stateMutability: 'nonpayable',
  type: 'function'
}, {
  constant: false,
  inputs: [{
    name: '_manager',
    type: 'address'
  }, {
    name: '_permissionName',
    type: 'string'
  }],
  name: 'grantManagerPermission',
  outputs: [],
  payable: false,
  stateMutability: 'nonpayable',
  type: 'function'
}, {
  constant: true,
  inputs: [],
  name: 'getOwner',
  outputs: [{
    name: '',
    type: 'address'
  }],
  payable: false,
  stateMutability: 'view',
  type: 'function'
}, {
  constant: false,
  inputs: [{
    name: '_target',
    type: 'address'
  }, {
    name: '_suppliedGas',
    type: 'uint256'
  }, {
    name: '_ethValue',
    type: 'uint256'
  }, {
    name: '_transactionBytecode',
    type: 'bytes'
  }],
  name: 'executeCall',
  outputs: [],
  payable: false,
  stateMutability: 'nonpayable',
  type: 'function'
}, {
  constant: true,
  inputs: [],
  name: 'getCrydrStorageAddress',
  outputs: [{
    name: '',
    type: 'address'
  }],
  payable: false,
  stateMutability: 'view',
  type: 'function'
}, {
  constant: false,
  inputs: [{
    name: '_proposedOwner',
    type: 'address'
  }],
  name: 'createOwnershipOffer',
  outputs: [],
  payable: false,
  stateMutability: 'nonpayable',
  type: 'function'
}, {
  constant: true,
  inputs: [{
    name: '_manager',
    type: 'address'
  }],
  name: 'isManagerEnabled',
  outputs: [{
    name: '',
    type: 'bool'
  }],
  payable: false,
  stateMutability: 'view',
  type: 'function'
}, {
  constant: false,
  inputs: [{
    name: '_account',
    type: 'address'
  }, {
    name: '_value',
    type: 'uint256'
  }],
  name: 'burn',
  outputs: [],
  payable: false,
  stateMutability: 'nonpayable',
  type: 'function'
}, {
  constant: true,
  inputs: [],
  name: 'getAssetIDHash',
  outputs: [{
    name: '',
    type: 'bytes32'
  }],
  payable: false,
  stateMutability: 'view',
  type: 'function'
}, {
  constant: false,
  inputs: [],
  name: 'unpauseContract',
  outputs: [],
  payable: false,
  stateMutability: 'nonpayable',
  type: 'function'
}, {
  constant: true,
  inputs: [{
    name: '_viewApiStandardName',
    type: 'string'
  }],
  name: 'getCrydrViewAddress',
  outputs: [{
    name: '',
    type: 'address'
  }],
  payable: false,
  stateMutability: 'view',
  type: 'function'
}, {
  constant: false,
  inputs: [{
    name: '_msgsender',
    type: 'address'
  }, {
    name: '_to',
    type: 'address'
  }, {
    name: '_value',
    type: 'uint256'
  }],
  name: 'transfer',
  outputs: [],
  payable: false,
  stateMutability: 'nonpayable',
  type: 'function'
}, {
  constant: false,
  inputs: [{
    name: '_from',
    type: 'address'
  }, {
    name: '_to',
    type: 'address'
  }, {
    name: '_value',
    type: 'uint256'
  }],
  name: 'chargeJNT',
  outputs: [],
  payable: false,
  stateMutability: 'nonpayable',
  type: 'function'
}, {
  constant: true,
  inputs: [],
  name: 'getTotalSupply',
  outputs: [{
    name: '',
    type: 'uint256'
  }],
  payable: false,
  stateMutability: 'view',
  type: 'function'
}, {
  constant: false,
  inputs: [{
    name: '_account',
    type: 'address'
  }, {
    name: '_value',
    type: 'uint256'
  }],
  name: 'blockAccountFunds',
  outputs: [],
  payable: false,
  stateMutability: 'nonpayable',
  type: 'function'
}, {
  constant: false,
  inputs: [{
    name: '_target',
    type: 'address'
  }, {
    name: '_suppliedGas',
    type: 'uint256'
  }, {
    name: '_transactionBytecode',
    type: 'bytes'
  }],
  name: 'executeDelegatecall',
  outputs: [],
  payable: false,
  stateMutability: 'nonpayable',
  type: 'function'
}, {
  constant: true,
  inputs: [{
    name: '_crydrViewAddress',
    type: 'address'
  }],
  name: 'isCrydrViewAddress',
  outputs: [{
    name: '',
    type: 'bool'
  }],
  payable: false,
  stateMutability: 'view',
  type: 'function'
}, {
  constant: false,
  inputs: [{
    name: '_manager',
    type: 'address'
  }],
  name: 'disableManager',
  outputs: [],
  payable: false,
  stateMutability: 'nonpayable',
  type: 'function'
}, {
  constant: true,
  inputs: [{
    name: '_viewApiStandardName',
    type: 'string'
  }],
  name: 'isCrydrViewRegistered',
  outputs: [{
    name: '',
    type: 'bool'
  }],
  payable: false,
  stateMutability: 'view',
  type: 'function'
}, {
  constant: false,
  inputs: [{
    name: '_msgsender',
    type: 'address'
  }, {
    name: '_spender',
    type: 'address'
  }, {
    name: '_value',
    type: 'uint256'
  }],
  name: 'approve',
  outputs: [],
  payable: false,
  stateMutability: 'nonpayable',
  type: 'function'
}, {
  constant: false,
  inputs: [{
    name: '_newCrydrView',
    type: 'address'
  }, {
    name: '_viewApiStandardName',
    type: 'string'
  }],
  name: 'setCrydrView',
  outputs: [],
  payable: false,
  stateMutability: 'nonpayable',
  type: 'function'
}, {
  constant: true,
  inputs: [],
  name: 'getProposedOwner',
  outputs: [{
    name: '',
    type: 'address'
  }],
  payable: false,
  stateMutability: 'view',
  type: 'function'
}, {
  constant: false,
  inputs: [],
  name: 'acceptOwnershipOffer',
  outputs: [],
  payable: false,
  stateMutability: 'nonpayable',
  type: 'function'
}, {
  constant: true,
  inputs: [{
    name: '_owner',
    type: 'address'
  }],
  name: 'getBalance',
  outputs: [{
    name: '',
    type: 'uint256'
  }],
  payable: false,
  stateMutability: 'view',
  type: 'function'
}, {
  inputs: [],
  payable: false,
  stateMutability: 'nonpayable',
  type: 'constructor'
}, {
  anonymous: false,
  inputs: [{
    indexed: true,
    name: 'payableservice',
    type: 'address'
  }, {
    indexed: true,
    name: 'from',
    type: 'address'
  }, {
    indexed: true,
    name: 'to',
    type: 'address'
  }, {
    indexed: false,
    name: 'value',
    type: 'uint256'
  }],
  name: 'JNTChargedEvent',
  type: 'event'
}, {
  anonymous: false,
  inputs: [{
    indexed: true,
    name: 'crydrstorage',
    type: 'address'
  }],
  name: 'CrydrStorageChangedEvent',
  type: 'event'
}, {
  anonymous: false,
  inputs: [{
    indexed: true,
    name: 'crydrview',
    type: 'address'
  }, {
    indexed: false,
    name: 'standardname',
    type: 'string'
  }],
  name: 'CrydrViewAddedEvent',
  type: 'event'
}, {
  anonymous: false,
  inputs: [{
    indexed: true,
    name: 'crydrview',
    type: 'address'
  }, {
    indexed: false,
    name: 'standardname',
    type: 'string'
  }],
  name: 'CrydrViewRemovedEvent',
  type: 'event'
}, {
  anonymous: false,
  inputs: [{
    indexed: true,
    name: 'target',
    type: 'address'
  }, {
    indexed: false,
    name: 'suppliedGas',
    type: 'uint256'
  }, {
    indexed: false,
    name: 'ethValue',
    type: 'uint256'
  }, {
    indexed: false,
    name: 'transactionBytecodeHash',
    type: 'bytes32'
  }],
  name: 'CallExecutedEvent',
  type: 'event'
}, {
  anonymous: false,
  inputs: [{
    indexed: true,
    name: 'target',
    type: 'address'
  }, {
    indexed: false,
    name: 'suppliedGas',
    type: 'uint256'
  }, {
    indexed: false,
    name: 'transactionBytecodeHash',
    type: 'bytes32'
  }],
  name: 'DelegatecallExecutedEvent',
  type: 'event'
}, {
  anonymous: false,
  inputs: [],
  name: 'PauseEvent',
  type: 'event'
}, {
  anonymous: false,
  inputs: [],
  name: 'UnpauseEvent',
  type: 'event'
}, {
  anonymous: false,
  inputs: [{
    indexed: true,
    name: 'manager',
    type: 'address'
  }],
  name: 'ManagerEnabledEvent',
  type: 'event'
}, {
  anonymous: false,
  inputs: [{
    indexed: true,
    name: 'manager',
    type: 'address'
  }],
  name: 'ManagerDisabledEvent',
  type: 'event'
}, {
  anonymous: false,
  inputs: [{
    indexed: true,
    name: 'manager',
    type: 'address'
  }, {
    indexed: false,
    name: 'permission',
    type: 'string'
  }],
  name: 'ManagerPermissionGrantedEvent',
  type: 'event'
}, {
  anonymous: false,
  inputs: [{
    indexed: true,
    name: 'manager',
    type: 'address'
  }, {
    indexed: false,
    name: 'permission',
    type: 'string'
  }],
  name: 'ManagerPermissionRevokedEvent',
  type: 'event'
}, {
  anonymous: false,
  inputs: [{
    indexed: true,
    name: 'newowner',
    type: 'address'
  }],
  name: 'OwnerAssignedEvent',
  type: 'event'
}, {
  anonymous: false,
  inputs: [{
    indexed: true,
    name: 'currentowner',
    type: 'address'
  }, {
    indexed: true,
    name: 'proposedowner',
    type: 'address'
  }],
  name: 'OwnershipOfferCreatedEvent',
  type: 'event'
}, {
  anonymous: false,
  inputs: [{
    indexed: true,
    name: 'currentowner',
    type: 'address'
  }, {
    indexed: true,
    name: 'proposedowner',
    type: 'address'
  }],
  name: 'OwnershipOfferAcceptedEvent',
  type: 'event'
}, {
  anonymous: false,
  inputs: [{
    indexed: true,
    name: 'currentowner',
    type: 'address'
  }, {
    indexed: true,
    name: 'proposedowner',
    type: 'address'
  }],
  name: 'OwnershipOfferCancelledEvent',
  type: 'event'
}];
var ERC20 = [{
  constant: false,
  inputs: [{
    name: '_spender',
    type: 'address'
  }, {
    name: '_value',
    type: 'uint256'
  }],
  name: 'approve',
  outputs: [{
    name: 'success',
    type: 'bool'
  }],
  payable: false,
  type: 'function'
}, {
  constant: true,
  inputs: [],
  name: 'totalSupply',
  outputs: [{
    name: '',
    type: 'uint256'
  }],
  payable: false,
  type: 'function'
}, {
  constant: false,
  inputs: [{
    name: '_from',
    type: 'address'
  }, {
    name: '_to',
    type: 'address'
  }, {
    name: '_value',
    type: 'uint256'
  }],
  name: 'transferFrom',
  outputs: [{
    name: 'success',
    type: 'bool'
  }],
  payable: false,
  type: 'function'
}, {
  constant: true,
  inputs: [{
    name: '_owner',
    type: 'address'
  }],
  name: 'balanceOf',
  outputs: [{
    name: 'balance',
    type: 'uint256'
  }],
  payable: false,
  type: 'function'
}, {
  constant: false,
  inputs: [{
    name: '_to',
    type: 'address'
  }, {
    name: '_value',
    type: 'uint256'
  }],
  name: 'transfer',
  outputs: [{
    name: 'success',
    type: 'bool'
  }],
  payable: false,
  type: 'function'
}, {
  constant: true,
  inputs: [{
    name: '_owner',
    type: 'address'
  }, {
    name: '_spender',
    type: 'address'
  }],
  name: 'allowance',
  outputs: [{
    name: 'remaining',
    type: 'uint256'
  }],
  payable: false,
  type: 'function'
}, {
  anonymous: false,
  inputs: [{
    indexed: true,
    name: 'from',
    type: 'address'
  }, {
    indexed: true,
    name: 'to',
    type: 'address'
  }, {
    indexed: false,
    name: 'value',
    type: 'uint256'
  }],
  name: 'Transfer',
  type: 'event'
}, {
  anonymous: false,
  inputs: [{
    indexed: true,
    name: 'owner',
    type: 'address'
  }, {
    indexed: true,
    name: 'spender',
    type: 'address'
  }, {
    indexed: false,
    name: 'value',
    type: 'uint256'
  }],
  name: 'Approval',
  type: 'event'
}];
var ERC20Mintable = [{
  constant: false,
  inputs: [{
    name: '_owner',
    type: 'address'
  }, {
    name: '_value',
    type: 'uint256'
  }],
  name: 'emitMintEvent',
  outputs: [],
  payable: false,
  stateMutability: 'nonpayable',
  type: 'function'
}, {
  constant: false,
  inputs: [{
    name: '_owner',
    type: 'address'
  }, {
    name: '_value',
    type: 'uint256'
  }],
  name: 'emitBurnEvent',
  outputs: [],
  payable: false,
  stateMutability: 'nonpayable',
  type: 'function'
}, {
  anonymous: false,
  inputs: [{
    indexed: true,
    name: 'owner',
    type: 'address'
  }, {
    indexed: false,
    name: 'value',
    type: 'uint256'
  }],
  name: 'MintEvent',
  type: 'event'
}, {
  anonymous: false,
  inputs: [{
    indexed: true,
    name: 'owner',
    type: 'address'
  }, {
    indexed: false,
    name: 'value',
    type: 'uint256'
  }],
  name: 'BurnEvent',
  type: 'event'
}];
var ERC20Named = [{
  constant: true,
  inputs: [],
  name: 'name',
  outputs: [{
    name: '',
    type: 'string'
  }],
  payable: false,
  type: 'function'
}, {
  constant: true,
  inputs: [],
  name: 'decimals',
  outputs: [{
    name: '',
    type: 'uint32'
  }],
  payable: false,
  type: 'function'
}, {
  constant: true,
  inputs: [],
  name: 'getSymbolHash',
  outputs: [{
    name: '',
    type: 'bytes32'
  }],
  payable: false,
  type: 'function'
}, {
  constant: true,
  inputs: [],
  name: 'symbol',
  outputs: [{
    name: '',
    type: 'string'
  }],
  payable: false,
  type: 'function'
}, {
  constant: true,
  inputs: [],
  name: 'getNameHash',
  outputs: [{
    name: '',
    type: 'bytes32'
  }],
  payable: false,
  type: 'function'
}];
exports.default = { Controller: Controller, ERC20: ERC20, ERC20Mintable: ERC20Mintable, ERC20Named: ERC20Named };