'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.mint = mint;
exports.burn = burn;

var _contractMethod = require('./contractMethod');

var _contractMethod2 = _interopRequireDefault(_contractMethod);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var interfaceName = 'Controller';

/**
 * @async
 * @function mint
 *
 * @description Mint tokens
 *
 * @param {object} props - API function properties
 * @param {string} props.rpcaddr - RPC address of Ethereum node to connect on
 * @param {number} props.rpcport - RPC port of Ethereum node to connect on
 * @param {string} props.contractAddress - Contract address
 * @param {string} props.privateKey - Private key (64 hex symbols, without '0x' prefix)
 * @param {string} props.account - Address of account to mint tokens to
 * @param {BigNumber} props.value - Transaction value
 * @param {BigNumber} [props.gasLimit] - Gas limit for the transaction
 * @param {BigNumber} [props.gasPrice] - Gas price for the transaction
 * @param {number} [props.nonce] - Nonce for the transaction
 * @param {boolean} [props.ssl] - Defines using of ssl for connection or not
 *
 * @returns Promise that will be resolved with the hash of created contract transaction
 */
/**
 * @file Exposes Controller API
 * @author Ivan Violentov <ivan.violentov@jibrel.network>
 */

function mint() {
  var props = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var account = props.account,
      value = props.value;


  return _contractMethod2.default.sendTransaction({
    props: props,
    interfaceName: interfaceName,
    method: 'mint',
    args: [account, value]
  });
}

/**
 * @async
 * @function burn
 *
 * @description Burn tokens
 *
 * @param {object} props - API function properties
 * @param {string} props.rpcaddr - RPC address of Ethereum node to connect on
 * @param {number} props.rpcport - RPC port of Ethereum node to connect on
 * @param {string} props.contractAddress - Contract address
 * @param {string} props.privateKey - Private key (64 hex symbols, without '0x' prefix)
 * @param {string} props.account - Address of account to burn tokens from
 * @param {BigNumber} props.value - Transaction value
 * @param {BigNumber} [props.gasLimit] - Gas limit for the transaction
 * @param {BigNumber} [props.gasPrice] - Gas price for the transaction
 * @param {number} [props.nonce] - Nonce for the transaction
 * @param {boolean} [props.ssl] - Defines using of ssl for connection or not
 *
 * @returns Promise that will be resolved with the hash of created contract transaction
 */
function burn() {
  var props = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var account = props.account,
      value = props.value;


  return _contractMethod2.default.sendTransaction({
    props: props,
    interfaceName: interfaceName,
    method: 'burn',
    args: [account, value]
  });
}

exports.default = { mint: mint, burn: burn };