'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.MintEvent = MintEvent;
exports.BurnEvent = BurnEvent;
exports.allEvents = allEvents;
exports.getPastEvents = getPastEvents;

var _contractMethod = require('./contractMethod');

var _contractMethod2 = _interopRequireDefault(_contractMethod);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var interfaceName = 'ERC20Mintable';

/**
 * @async
 * @function MintEvent
 *
 * @description Subscribes to MintEvent event
 *
 * @param {object} props - API function properties
 * @param {string} props.rpcaddr - RPC address of Ethereum node to connect on
 * @param {number} props.rpcport - RPC port of Ethereum node to connect on
 * @param {string} props.contractAddress - Contract address
 * @param {object} [props.options] - Event options (@see subscribe)
 * @param {function} [props.callback] - Event callback (@see subscribe)
 * @param {boolean} [props.ssl] - Defines using of ssl for connection or not
 *
 * @returns Promise that will be resolved with the event emitter (@see subsribe)
 */
/**
 * @file Exposes ERC20Mintable API
 * @author Ivan Violentov <ivan.violentov@jibrel.network>
 */

function MintEvent(props) {
  return _contractMethod2.default.subscribeToEvent({ props: props, interfaceName: interfaceName, method: 'MintEvent' });
}

/**
 * @async
 * @function BurnEvent
 *
 * @description Subscribes to BurnEvent event
 *
 * @param {object} props - API function properties
 * @param {string} props.rpcaddr - RPC address of Ethereum node to connect on
 * @param {number} props.rpcport - RPC port of Ethereum node to connect on
 * @param {string} props.contractAddress - Contract address
 * @param {object} [props.options] - Event options (@see subscribe)
 * @param {function} [props.callback] - Event callback (@see subscribe)
 * @param {boolean} [props.ssl] - Defines using of ssl for connection or not
 *
 * @returns Promise that will be resolved with the event emitter (@see subsribe)
 */
function BurnEvent(props) {
  return _contractMethod2.default.subscribeToEvent({ props: props, interfaceName: interfaceName, method: 'BurnEvent' });
}

/**
 * @async
 * @function allEvents
 *
 * @description Subscribes to all contract events
 *
 * @param {object} props - API function properties
 * @param {string} props.rpcaddr - RPC address of Ethereum node to connect on
 * @param {number} props.rpcport - RPC port of Ethereum node to connect on
 * @param {string} props.contractAddress - Contract address
 * @param {object} [props.options] - Event options (@see subscribe)
 * @param {function} [props.callback] - Event callback (@see subscribe)
 * @param {boolean} [props.ssl] - Defines using of ssl for connection or not
 *
 * @returns Promise that will be resolved with the event emitter (@see subsribe)
 */
function allEvents(props) {
  return _contractMethod2.default.subscribeToEvent({ props: props, interfaceName: interfaceName, method: 'allEvents' });
}

/**
 * @async
 * @function getPastEvents
 *
 * @description Gets past events
 *
 * @param {object} props - API function properties
 * @param {string} props.rpcaddr - RPC address of Ethereum node to connect on
 * @param {number} props.rpcport - RPC port of Ethereum node to connect on
 * @param {string} props.contractAddress - Contract address
 * @param {string} props.event - Event name (@see subscribe)
 * @param {object} [props.options] - Event options (@see subscribe)
 * @param {boolean} [props.ssl] - Defines using of ssl for connection or not
 *
 * @returns Promise that will be resolved with the event logs (@see getPast)
 */
function getPastEvents(props) {
  return _contractMethod2.default.getPastEvents({ props: props, interfaceName: interfaceName, method: 'getPastEvents' });
}

exports.default = { MintEvent: MintEvent, BurnEvent: BurnEvent, allEvents: allEvents, getPastEvents: getPastEvents };