'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _regenerator = require('babel-runtime/regenerator');

var _regenerator2 = _interopRequireDefault(_regenerator);

var _asyncToGenerator2 = require('babel-runtime/helpers/asyncToGenerator');

var _asyncToGenerator3 = _interopRequireDefault(_asyncToGenerator2);

var _toConsumableArray2 = require('babel-runtime/helpers/toConsumableArray');

var _toConsumableArray3 = _interopRequireDefault(_toConsumableArray2);

/**
 * @async
 * @function sendETHTransaction
 *
 * @description Sends transaction
 *
 * @param {object} payload - Payload object
 * @param {object} payload.props - Method properties
 * @param {string} payload.props.privateKey - Private key (64 hex symbols, without '0x' prefix)
 * @param {string} payload.props.to - Address of the transaction receiver
 * @param {BigNumber} payload.props.value - Transaction value
 * @param {BigNumber} [payload.props.gasLimit] - Gas limit for the transaction
 * @param {BigNumber} [payload.props.gasPrice] - Gas price for the transaction
 * @param {number} [payload.props.nonce] - Nonce for the transaction
 * @param {string} [payload.props.data] - Transaction data
 *
 * @returns Promise that will be resolved with the hash of the transaction
 */
var sendETHTransaction = function () {
  var _ref = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee(payload) {
    var _payload$props, privateKey, to, value, gasLimit, gasPrice, nonce, data, address, rawTx, signedTx;

    return _regenerator2.default.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            _payload$props = payload.props, privateKey = _payload$props.privateKey, to = _payload$props.to, value = _payload$props.value, gasLimit = _payload$props.gasLimit, gasPrice = _payload$props.gasPrice, nonce = _payload$props.nonce, data = _payload$props.data;
            address = (0, _getAddressFromPrivateKey2.default)(privateKey);
            _context.next = 4;
            return (0, _txUtils.getRawTx)({ gasLimit: gasLimit, gasPrice: gasPrice, nonce: nonce, address: address, data: data, to: to, value: value });

          case 4:
            rawTx = _context.sent;
            signedTx = (0, _txUtils.signTx)(rawTx, privateKey);
            return _context.abrupt('return', _bluebird2.default.promisify(jWeb3.eth.sendRawTransaction)(signedTx).timeout(_config2.default.promiseTimeout, new Error('Can not call web3.eth.sendRawTransaction within ' + _config2.default.promiseTimeout + 'ms')));

          case 7:
          case 'end':
            return _context.stop();
        }
      }
    }, _callee, this);
  }));

  return function sendETHTransaction(_x) {
    return _ref.apply(this, arguments);
  };
}();

/**
 * @function filterETHLogs
 *
 * @description Initializes filter object
 *
 * @param {object} payload - Payload object
 * @param {object} payload.props - API function properties
 * @param {object} [payload.props.options] - Filter options (@see filter)
 *
 * @returns {object} The event emitter (@see subscribe)
 */


var _bluebird = require('bluebird');

var _bluebird2 = _interopRequireDefault(_bluebird);

var _getAddressFromPrivateKey = require('../getAddressFromPrivateKey');

var _getAddressFromPrivateKey2 = _interopRequireDefault(_getAddressFromPrivateKey);

var _validation = require('../../validation');

var _validation2 = _interopRequireDefault(_validation);

var _checkWeb = require('../../utils/checkWeb3');

var _checkWeb2 = _interopRequireDefault(_checkWeb);

var _logUtils = require('../../utils/logUtils');

var _txUtils = require('../../utils/txUtils');

var _config = require('../../config');

var _config2 = _interopRequireDefault(_config);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * @async
 * @function call
 *
 * @description Wrapper for callETHMethod function (@see callETHMethod)
 */
function call(payload) {
  return prepareETHMethod(payload).then(callETHMethod);
}

/**
 * @async
 * @function sendTransaction
 *
 * @description Wrapper for sendETHTransaction function (@see sendETHTransaction)
 */
/**
 * @file Manages web3.eth wrapper
 * @author Ivan Violentov <ivan.violentov@jibrel.network>
 */

function sendTransaction(payload) {
  return prepareETHMethod(payload).then(sendETHTransaction);
}

/**
 * @async
 * @function filterLogs
 *
 * @description Wrapper for filterETHLogs function (@see filterETHLogs)
 */
function filterLogs(payload) {
  return prepareETHMethod(payload).then(filterETHLogs);
}

/**
 * @async
 * @function getPastLogs
 *
 * @description Wrapper for getPastETHLogs function (@see getPastETHLogs)
 */
function getPastLogs(payload) {
  return prepareETHMethod(payload).then(getPastETHLogs);
}

/**
 * @async
 * @function estimateGas
 *
 * @description Wrapper for estimateETHGas function (@see estimateETHGas)
 */
function estimateGas(payload) {
  return prepareETHMethod(payload).then(estimateETHGas);
}

function prepareETHMethod(payload) {
  return _bluebird2.default.bind(this, payload).then(_validation2.default).then(_checkWeb2.default);
}

/**
 * @async
 * @function callETHMethod
 *
 * @description Calls specific web3.eth method with provided arguments
 *
 * @param {object} payload - Payload object
 * @param {string} payload.method - Method name
 * @param {array} payload.args - Method arguments
 *
 * @returns Promise that will be resolved with the result of web3.eth method execution
 */
function callETHMethod(payload) {
  var method = payload.method,
      args = payload.args;


  return _bluebird2.default.promisify(jWeb3.eth[method]).apply(undefined, (0, _toConsumableArray3.default)(args)).timeout(_config2.default.promiseTimeout, new Error('Can not call web3.eth.' + method + ' within ' + _config2.default.promiseTimeout + 'ms'));
}function filterETHLogs(payload) {
  return (0, _logUtils.filter)(payload.props.options);
}

/**
 * @async
 * @function getPastETHLogs
 *
 * @description Gets past ETH logs
 *
 * @param {object} payload - Payload object
 * @param {object} payload.props - API function properties
 * @param {object} [payload.props.options] - Event options (@see getLogs)
 *
 * @returns Promise that will be resolved with past logs (@see getLogs)
 */
function getPastETHLogs(payload) {
  return (0, _logUtils.getLogs)(payload.props.options);
}

/**
 * @async
 * @function estimateETHGas
 *
 * @description Gets estimate gas for the transaction
 *
 * @param {object} payload - Payload object
 * @param {object} payload.props - Method properties
 *
 * @returns Promise that will be resolved with estimate gas value
 */
function estimateETHGas(payload) {
  return (0, _txUtils.getGasLimit)(payload.props);
}

exports.default = { call: call, sendTransaction: sendTransaction, filterLogs: filterLogs, getPastLogs: getPastLogs, estimateGas: estimateGas };