'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends2 = require('babel-runtime/helpers/extends');

var _extends3 = _interopRequireDefault(_extends2);

var _joiBrowser = require('joi-browser');

var _joiBrowser2 = _interopRequireDefault(_joiBrowser);

var _validationRules = require('../validationRules');

var _validationRules2 = _interopRequireDefault(_validationRules);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * @file Exposes validation schemas for ETH interface
 * @author Ivan Violentov <ivan.violentov@jibrel.network>
 */

var sendTransaction = _joiBrowser2.default.object().keys((0, _extends3.default)({}, _validationRules.generalETHKeys, {
  privateKey: _validationRules2.default.privateKey.required(),
  to: _validationRules2.default.address.required(),
  value: _validationRules2.default.value.required(),
  gasLimit: _validationRules2.default.gasLimit,
  gasPrice: _validationRules2.default.gasPrice,
  nonce: _validationRules2.default.nonce,
  data: _validationRules2.default.data
}));

var getBalance = _joiBrowser2.default.object().keys((0, _extends3.default)({}, _validationRules.generalETHKeys, {
  address: _validationRules2.default.address.required(),
  defaultBlock: _validationRules2.default.address
}));

var getBlockNumber = _joiBrowser2.default.object().keys((0, _extends3.default)({}, _validationRules.generalETHKeys));

var getBlock = _joiBrowser2.default.object().keys((0, _extends3.default)({}, _validationRules.generalETHKeys, {
  blockId: _validationRules2.default.blockId,
  returnTransactionObjects: _validationRules2.default.returnTransactionObjects
}));

var getTransaction = _joiBrowser2.default.object().keys((0, _extends3.default)({}, _validationRules.generalETHKeys, {
  transactionHash: _validationRules2.default.transactionHash.required()
}));

var getTransactionReceipt = _joiBrowser2.default.object().keys((0, _extends3.default)({}, _validationRules.generalETHKeys, {
  transactionHash: _validationRules2.default.transactionHash.required()
}));

var getLogsFilter = _joiBrowser2.default.object().keys((0, _extends3.default)({}, _validationRules.generalETHKeys, {
  options: _validationRules2.default.logsOptions
}));

var getPastLogs = _joiBrowser2.default.object().keys((0, _extends3.default)({}, _validationRules.generalETHKeys, {
  options: _validationRules2.default.logsOptions
}));

var estimateGas = _joiBrowser2.default.object().keys((0, _extends3.default)({}, _validationRules.generalETHKeys, {
  to: _validationRules2.default.address.required(),
  value: _validationRules2.default.value.required(),
  data: _validationRules2.default.data
}));

exports.default = {
  sendTransaction: sendTransaction,
  getBalance: getBalance,
  getBlockNumber: getBlockNumber,
  getBlock: getBlock,
  getTransaction: getTransaction,
  getTransactionReceipt: getTransactionReceipt,
  getLogsFilter: getLogsFilter,
  getPastLogs: getPastLogs,
  estimateGas: estimateGas
};